==> amity-sdk-7.5.1-sources.jar: main/com/amity/socialcloud/sdk/social/domain/post/create/PollPostCreateUseCase.kt <==
package com.amity.socialcloud.sdk.social.domain.post.create

import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.PostRepository
import com.amity.socialcloud.sdk.social.domain.post.PostGetUseCase
import com.ekoapp.ekosdk.internal.usecase.post.PostCreateUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single


internal class PollPostCreateUseCase : PostCreateUseCase {

    fun execute(
        targetType: String,
        targetId: String,
        pollId: String,
        text: String,
        metadata: JsonObject?,
        mentionUserIds: List<String>?
    ): Single<AmityPost> {
        return PostRepository().createPostV4(
            targetType = targetType,
            targetId = targetId,
            data = composeData(pollId = pollId, text = text),
            dataType = AmityPost.DataType.POLL,
            attachments = null,
            metadata = metadata,
            mentionees = mapMentionees(mentionUserIds)
        ).flatMap {
            val post = PostGetUseCase().execute(it)
            if (post != null) {
                Single.just(post)
            } else {
                Single.error(
                    AmityException.create(
                        "Post not found",
                        null,
                        AmityError.ITEM_NOT_FOUND
                    )
                )
            }
        }
    }

    private fun composeData(pollId: String, text: String): JsonObject {
        return JsonObject()
            .apply { addProperty("pollId", pollId) }
            .apply { addProperty("text", text) }
    }

}

==> amity-sdk-7.15.0-sources.jar: main/com/amity/socialcloud/sdk/social/domain/post/create/PollPostCreateUseCase.kt <==
package com.amity.socialcloud.sdk.social.domain.post.create

import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.PostRepository
import com.amity.socialcloud.sdk.social.domain.post.PostGetUseCase
import com.ekoapp.ekosdk.internal.usecase.post.PostCreateUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single


internal class PollPostCreateUseCase : PostCreateUseCase {

    fun execute(
        targetType: String,
        targetId: String,
        pollId: String,
        text: String,
        title: String?,
        metadata: JsonObject?,
        mentionUserIds: List<String>?,
        hashtags: List<String>?,
        tags: List<String>? = null,
    ): Single<AmityPost> {
        return PostRepository().createPostV4(
            targetType = targetType,
            targetId = targetId,
            data = composeData(pollId = pollId, text = text, title = title),
            dataType = AmityPost.DataType.POLL,
            attachments = null,
            metadata = metadata,
            mentionees = mapMentionees(mentionUserIds),
            hashtags = hashtags,
            tags = tags,
        ).flatMap {
            val post = PostGetUseCase().execute(it)
            if (post != null) {
                Single.just(post)
            } else {
                Single.error(
                    AmityException.create(
                        "Post not found",
                        null,
                        AmityError.ITEM_NOT_FOUND
                    )
                )
            }
        }
    }

    private fun composeData(pollId: String, text: String, title: String?): JsonObject {
        return JsonObject()
            .apply {
                addProperty("pollId", pollId)
                addProperty("text", text)
                title?.takeIf { it.isNotBlank() }?.let {
                    addProperty("title", it)
                }
            }
    }
}
